import json
import sys
from getpass import getpass
import hashlib

PWDB_PATH = 'pwdb.json'

def hashing(password):
    pwd_string = bytes(str(password), 'utf-8')
    hash_pwd = hashlib.sha256(pwd_string).hexdigest()
    return hash_pwd

def get_credentials():
    username = input('Enter your username: ')
    password = getpass('Enter your password: ')
    hash_pwd = hashing(password)
    return (username, hash_pwd)

def authenticate(username, password, pwdb):
    return password == pwdb[username]

def add_user(username, pwdb):
    password = input(f'Enter password for {username}: ')
    pwdb[username] = hashing(password)
    return pwdb

def read_pwdb(PWDB_PATH):
    try:
        pwdb_file = open(PWDB_PATH, 'rt')
        pwdb = json.load(pwdb_file)
    except Exception:
        pwdb = {}
    return pwdb

def write_pwdb(pwdb, PWDB_PATH):
    pwdb_file = open(PWDB_PATH, 'wt')
    json.dump(pwdb, pwdb_file)


if __name__ == "__main__":
    PWDB_PATH = 'pwdb.json'
    pwdb = read_pwdb(PWDB_PATH)

    if len(sys.argv) > 1:
        pwdb = add_user(sys.argv[1], pwdb)
        write_pwdb(pwdb, PWDB_PATH)
    else:
        username, password = get_credentials()
        if username not in pwdb:
            print('Wrong username!')
        else:
            if authenticate(username, password, pwdb):
                print('Successfully authenticated!')
            else:
                print('Wrong password!')

